pub trait PluginGroup: Sized {
// Required method
fn build(self) -> PluginGroupBuilder;
// Provided methods
fn name() -> String { ... }
fn set<T: Plugin>(self, plugin: T) -> PluginGroupBuilder { ... }
}Expand description
Combines multiple Plugins into a single unit.
If you want an easier, but slightly more restrictive, method of implementing this trait, you
may be interested in the plugin_group! macro.
Required Methods
Sourcefn build(self) -> PluginGroupBuilder
fn build(self) -> PluginGroupBuilder
Configures the Plugins that are to be added.
Provided Methods
Sourcefn name() -> String
fn name() -> String
Configures a name for the PluginGroup which is primarily used for debugging.
Sourcefn set<T: Plugin>(self, plugin: T) -> PluginGroupBuilder
fn set<T: Plugin>(self, plugin: T) -> PluginGroupBuilder
Sets the value of the given Plugin, if it exists
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".